require 'spec_helper'

describe Conjur::API do 
  let(:username) { "user" }
  let(:api){ Conjur::API.new_from_key username, 'key' }
  let(:credentials) { { headers: { authorization: "Token token=\"stub\"" } } } #, username: username } }

  before do
    api.stub credentials: credentials
  end

  describe "#audit_send" do
    context "valid input" do
      let(:cert_store) { double(:cert_store) }
      before do
        stub_const 'OpenSSL::SSL::SSLContext::DEFAULT_CERT_STORE', cert_store
      end
      let(:http_parameters)  {
        {
          ssl_cert_store: cert_store,
          headers: credentials[:headers].merge(content_type: "text/plain"),
          method: :post ,
          url: "#{Conjur::Authz::API.host}/audit"
        } 
      }
  
      it "sends Hash as JSON" do
        event = { action: "login", user: "alice" }
        RestClient::Request.should_receive(:execute).with(
          http_parameters.merge( payload: event.to_json )
        )
        api.audit_send event
      end
      it "sends array as JSON" do
        events = [ { action: "login", user: "alice" }, { action: "sudo", user: "alice" } ]
        RestClient::Request.should_receive(:execute).with(
          http_parameters.merge( payload: events.to_json )
        )
        api.audit_send events
      end
  
      it "sends string as is (consider it preformatted JSON)" do
        events_serialized = "this is supposed to be JSON" 
        RestClient::Request.should_receive(:execute).with(
          http_parameters.merge( payload: events_serialized )
        )
        api.audit_send events_serialized
      end
    end
      
    it "rejects any other types of arguments" do
      expect { api.audit_send( api ) }.to raise_error(ArgumentError)
    end
  
  end
end